Updates the vertex attributes on a network for new nodes
incoming into that network, based on a set of rules for each
attribute that the user specifies in control.net().
Arguments
- dat
Main
netsim_datobject containing anetworkDynamicobject and other initialization information passed fromnetsim().- newNodes
Vector of nodal IDs for incoming nodes at the current time step.
- curr.tab
Current proportional distribution of all vertex attributes.
See also
copy_nwattr_to_datattr(), get_attr_prop(),
auto_update_attr().