copy_datattr_to_nwattr: Copy Vertex Attributes from the 'netsim_dat' List to the...

View source: R/net.fn.utils.R

copy_datattr_to_nwattrR Documentation

Copy Vertex Attributes from the netsim_dat List to the Network Objects

Description

Copies the vertex attributes stored on the main attr list of the netsim_dat object to each of the network objects stored on the netsim_dat object.

Usage

copy_datattr_to_nwattr(dat)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

Value

The updated netsim_dat main list object.

See Also

get_formula_term_attr(), get_attr_prop(), auto_update_attr(), and copy_nwattr_to_datattr().


EpiModel documentation built on March 19, 2026, 9:08 a.m.