copy_nwattr_to_datattr: Copy Vertex Attributes From Network to 'netsim_dat' List

View source: R/net.fn.utils.R

copy_nwattr_to_datattrR Documentation

Copy Vertex Attributes From Network to netsim_dat List

Description

Copies the vertex attributes stored on the network object to the main attr list in the netsim_dat data object.

Usage

copy_nwattr_to_datattr(dat, nw)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

nw

Network from which to copy vertex attributes.

Value

The updated netsim_dat main list object.

See Also

get_formula_term_attr(), get_attr_prop(), auto_update_attr(), and copy_datattr_to_nwattr().


EpiModel documentation built on March 19, 2026, 9:08 a.m.