get_attr_prop: Proportional Table of Vertex Attributes

View source: R/net.fn.utils.R

get_attr_propR Documentation

Proportional Table of Vertex Attributes

Description

Calculates the proportional distribution of each vertex attribute contained in a network.

Usage

get_attr_prop(dat, nwterms)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

nwterms

Vector of attributes on the network object, usually as output of get_formula_term_attr().

Value

A table containing the proportional distribution of each attribute in nwterms.

See Also

get_formula_term_attr(), copy_nwattr_to_datattr(), auto_update_attr().


EpiModel documentation built on March 19, 2026, 9:08 a.m.