get_formula_term_attr: Output ERGM Formula Attributes into a Character Vector

View source: R/net.fn.utils.R

get_formula_term_attrR Documentation

Output ERGM Formula Attributes into a Character Vector

Description

Given a formation formula for a network model, outputs a character vector of vertex attributes to be used in netsim() simulations.

Usage

get_formula_term_attr(form, nw)

Arguments

form

An ERGM model formula.

nw

A network object.

Value

A character vector of vertex attributes.


EpiModel documentation built on March 19, 2026, 9:08 a.m.