Skip to contents

Get the List of Modules

Usage

get_modules(dat)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

Value

A named list of modules to be run by the model