R/get.R
get_nwparam.Rd
Extracts a list of network model parameters saved in the initialization module.
get_nwparam(x, network = 1)
Main netsim_dat data object used in netsim simulations.
netsim_dat
netsim
Network number, for simulations with multiple networks representing the population.