This function sets the initial disease status on the network given the specified initial conditions.
See also
This is an initialization module for icm().
This function sets the initial disease status on the network given the specified initial conditions.
This is an initialization module for icm().