Populate the Module List After the Initialization Module is run
Source:R/net.fn.modules.R
make_module_list.RdPopulate the Module List After the Initialization Module is run
Arguments
- dat
Main
netsim_datobject containing anetworkDynamicobject and other initialization information passed fromnetsim().