Handle the Logging of Traceback and Dumping of Frames on Error
Source:R/net.fn.logs.R
netsim_error_logger.RdIf control$.traceback.on.error == TRUE, this function prints the traceback
of the current simulation to STDIN. This is useful when ncores > 1 or in
HPC settings.
If control$.dump.frames.on.error == TRUE, this function saves a debugging
dump for "postmortem debugging". The dumps are named
"dump_%Y%m%d_%H%M%S_s.rda" and stored at the root of the working directory.
Arguments
- dat
Main
netsim_datobject containing anetworkDynamicobject and other initialization information passed fromnetsim().- s
The number of the simulation that failed