This function transfers the data from a list of the main
netsim_dat objects to the output out object at the
end of all simulations in netsim().
Value
A list of class netsim with the following elements:
param: the epidemic parameters passed into the model through
param, with additional parameters added as necessary.control: the control settings passed into the model through
control, with additional controls added as necessary.epi: a list of data frames, one for each epidemiological output from the model. Outputs for base models always include the size of each compartment, as well as flows in, out of, and between compartments.
stats: a list containing two sublists,
nwstatsfor any network statistics saved in the simulation, andtransmatfor the transmission matrix saved in the simulation. Seecontrol.net()for further details.network: a list of
networkDynamicobjects, one for each model simulation.