remove_modules: Remove a Set of Modules From the Module List

View source: R/net.fn.modules.R

remove_modulesR Documentation

Remove a Set of Modules From the Module List

Description

Remove a Set of Modules From the Module List

Usage

remove_modules(dat, names.to.remove)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

names.to.remove

a character vector containing the name of the modules to remove.

Value

The updated netsim_dat main list object.


EpiModel documentation built on March 19, 2026, 9:08 a.m.