resim_nets: Resimulate Dynamic Network at Time 2+

View source: R/net.mod.simnet.R

resim_netsR Documentation

Resimulate Dynamic Network at Time 2+

Description

This function resimulates the dynamic network in stochastic network models simulated in netsim() with dependence between the epidemic and demographic processes and the network structure.

Usage

resim_nets(dat, at)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

at

Current time step.

Value

The updated netsim_dat main list object.


EpiModel documentation built on March 19, 2026, 9:08 a.m.