This function transfers the data from the main icm_dat
class data object to the output out object at the end of
each simulation in icm().
Value
A list with the following elements:
param: the epidemic parameters passed into the model through
param.icm(), with additional parameters added as necessary.control: the control settings passed into the model through
control.icm(), with additional controls added as necessary.epi: a list of data frames, one for each epidemiological output from the model.