Skip to contents

Set the List of Modules

Usage

set_modules(dat, modules)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

modules

A named list of modules to be run by the model

Value

The updated netsim_dat main list object.