Tests whether the model output from an individual contact model is consistent with key balancing equations for compartment and flow sizes for each simulation for each time step.
Tests whether the model output from an individual contact model is consistent with key balancing equations for compartment and flow sizes for each simulation for each time step.