Skip to contents

Tests whether the model output from a network model is consistent with key balancing equations for compartment and flow sizes for each simulation for each time step.

Usage

test_net(x)

Arguments

x

An object of class netsim.