trigger_end_horizon: Function to Trigger the End Horizon

View source: R/net.fn.end.horizon.R

trigger_end_horizonR Documentation

Function to Trigger the End Horizon

Description

Function to Trigger the End Horizon

Usage

trigger_end_horizon(dat)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

Details

This function triggers the end horizon if a control end.horizon exists and its at value is equal to the current timestep. The end horizon consists on the removal of a set of modules from the module list.

Value

The updated netsim_dat main list object.


EpiModel documentation built on March 19, 2026, 9:08 a.m.