R/verbose.R
verbose.dcm.Rd
This function prints progress from deterministic compartmental models simulated with dcm() to the console.
dcm()
verbose.dcm(x, type, s = 1)
If the type is "startup", then an object of class control.dcm, otherwise the main df object in dcm runs.
type
control.dcm
df
dcm
Progress type, either of "startup" for starting messages before all runs, or "progress" for time step specific messages.
Current run number, if type is "progress".