Sets the controls for deterministic compartmental models
simulated with dcm().
Usage
control.dcm(
type,
nsteps,
dt = 1,
odemethod = "lsoda",
dede = FALSE,
new.mod = NULL,
sens.param = TRUE,
print.mod = FALSE,
verbose = FALSE,
...
)Arguments
- type
Disease type to be modeled, with the choice of
"SI"for Susceptible-Infected diseases,"SIR"for Susceptible-Infected-Recovered diseases, and"SIS"for Susceptible-Infected-Susceptible diseases.- nsteps
Number of time steps to solve the model over or vector of times to solve the model over. If the number of time steps, then this must be a positive integer of length 1.
- dt
Time unit for model solutions, with the default of 1. Model solutions for fractional time steps may be obtained by setting this to a number between 0 and 1.
- odemethod
Ordinary differential equation (ODE) integration method, with the default of
"lsoda"(seedeSolve::odefor other options).- dede
If
TRUE, use the delayed differential equation solver, which allows for time-lagged variables.- new.mod
If not running a base model type, a function with a new model to be simulated (see details).
- sens.param
If
TRUE, evaluate arguments in parameters or initial conditions with length greater than 1 as sensitivity analyses, with one model run per value. IfFALSE, one model will be run with parameters and initial conditions of arbitrary length (the model may error unless the model function is designed to accommodate vectors).- print.mod
If
TRUE, print the model form to the console.- verbose
If
TRUE, print model progress to the console.- ...
additional control settings passed to model.
Details
control.dcm sets the required control settings for any deterministic
compartmental models solved with the dcm() function. Controls are
required for both base model types and original models. For all base models,
the type argument is a necessary parameter and it has no default.
ODE Solver
As of EpiModel 2.5.5, the default ODE solver was changed from "rk4"
(fixed-step Runge-Kutta 4) to "lsoda" (adaptive step-size). The "lsoda"
method automatically adjusts its internal step size, providing numerical
stability across a wide range of parameter values. The fixed-step "rk4"
solver could produce numerical instability (negative compartment sizes, NaN
values) for models with high transmission rates or stiff dynamics. Users who
require the previous behavior can set odemethod = "rk4" explicitly.
New Model Functions
The form of the model function for base models may be displayed with the
print.mod argument set to TRUE. In this case, the model will
not be run. These model forms may be used as templates to write original
model functions.
These new models may be input and solved with dcm() using the
new.mod argument, which requires as input a model function.
See also
Use param.dcm() to specify model parameters and
init.dcm() to specify the initial conditions. Run the
parameterized model with dcm().