| control.icm | R Documentation |
Sets the controls for stochastic individual contact models
simulated with icm().
control.icm(type, nsteps, nsims = 1, verbose = FALSE, verbose.int = 0)
type |
Disease type to be modeled, with the choice of |
nsteps |
Number of time steps to solve the model over. This must be a positive integer. |
nsims |
Number of simulations to run. |
verbose |
If |
verbose.int |
Time step interval for printing progress to console, where
0 (the default) prints completion status of entire simulation and
positive integer |
control.icm sets the required control settings for any stochastic
individual contact model solved with the icm() function. ICM simulations
use the built-in SI, SIR, and SIS disease types only. The type argument
is required and has no default. For custom or extension epidemic models, use
the network model class via control.net() instead.
An EpiModel object of class control.icm.
Use param.icm() to specify model parameters and
init.icm() to specify the initial conditions. Run the
parameterized model with icm().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.