Skip to contents

Copies the vertex attributes stored on the main attr list of the netsim_dat object to each of the network objects stored on the netsim_dat object.

Usage

copy_datattr_to_nwattr(dat)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

Value

The updated netsim_dat main list object.