Skip to contents

Copies the vertex attributes stored on the network object to the main attr list in the netsim_dat data object.

Usage

copy_nwattr_to_datattr(dat, nw)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

nw

Network from which to copy vertex attributes.

Value

The updated netsim_dat main list object.