edges_correct: Adjustment for the Edges Coefficient with Changing Network...

View source: R/net.mod.simnet.R

edges_correctR Documentation

Adjustment for the Edges Coefficient with Changing Network Size

Description

Adjusts the edges coefficient in a dynamic network model simulated in netsim() to preserve the mean degree of nodes in the network. Requires at >= 2. Maintains the num(.g2) epi fields (initialized in sim_nets_t1()) for computing the coefficient adjustment.

Usage

edges_correct(dat, at)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

at

Current time step.

Value

The updated netsim_dat main list object.


EpiModel documentation built on March 19, 2026, 9:08 a.m.