Skip to contents

Calculates the proportional distribution of each vertex attribute contained in a network.

Usage

get_attr_prop(dat, nwterms)

Arguments

dat

Main netsim_dat object containing a networkDynamic object and other initialization information passed from netsim().

nwterms

Vector of attributes on the network object, usually as output of get_formula_term_attr().

Value

A table containing the proportional distribution of each attribute in nwterms.