This function transfers the data from the main df
object to the output out object at the end of each
run in dcm().
Arguments
- df
Main object in
dcm()simulations.- s
Current run number.
- param
Param list set in
param.dcm().- control
Control list set in
control.dcm().- out
Out list passed back in for updating at runs 2+.
Value
A list with the following elements:
param: the epidemic parameters passed into the model through
param.dcm(), with additional parameters added as necessary.control: the control settings passed into the model through
control.dcm(), with additional controls added as necessary.epi: a list of data frames, one for each epidemiological output from the model.