This function transfers the data from the main netsim_dat
object to the output out object at the end of each
simulation in netsim().
Arguments
- dat
Main
netsim_datobject containing anetworkDynamicobject and other initialization information passed fromnetsim().- s
Current simulation number.
- out
Out list passed back in for updating at simulations 2+.
Value
A list with the following elements:
param: the epidemic parameters passed into the model through
param.net(), with additional parameters added as necessary.control: the control settings passed into the model through
control.net(), with additional controls added as necessary.epi: a list of data frames, one for each epidemiological output from the model.
stats: a list containing two sublists,
nwstatsfor any network statistics saved in the simulation, andtransmatfor the transmission matrix saved in the simulation.network: a list of
networkDynamicobjects, one for each model simulation.