Set the List of Modules
Arguments
- dat
Main
netsim_datobject containing anetworkDynamicobject and other initialization information passed fromnetsim().- modules
A named list of modules to be run by the model
Set the List of Modules
Main netsim_dat object containing a networkDynamic
object and other initialization information passed from
netsim().
A named list of modules to be run by the model