Learn R Programming

EpiModel (version 2.6.2)

summary.dcm: Summary Model Statistics

Description

Extracts and prints model statistics solved with dcm.

Usage

# S3 method for dcm
summary(object, at, run = 1, digits = 3, ...)

Arguments

object

An EpiModel object of class dcm.

at

Time step for model statistics. Must be one of the times the model was solved over, held in control$timesteps, which for a model with a non-integer dt or an explicit vector of times in nsteps need be neither integer nor evenly spaced.

run

Model run number, for dcm class models with multiple runs (sensitivity analyses).

digits

Number of significant digits to print.

...

Additional summary function arguments (not used).

Details

This function provides summary statistics for the main epidemiological outcomes (state and transition size and prevalence) from a dcm model. Time-specific summary measures are provided, so it is necessary to input a time of interest. For multiple-run models (sensitivity analyses), input a model run number. See examples below.

See Also

dcm()

Examples

Run this code
## Deterministic SIR model with varying act.rate
param <- param.dcm(inf.prob = 0.2, act.rate = 2:4, rec.rate = 1/3,
                   a.rate = 0.011, ds.rate = 0.01,
                   di.rate = 0.03, dr.rate = 0.01)
init <- init.dcm(s.num = 1000, i.num = 1, r.num = 0)
control <- control.dcm(type = "SIR", nsteps = 50)
mod <- dcm(param, init, control)
summary(mod, at = 25, run = 1)
summary(mod, at = 25, run = 3)
summary(mod, at = 26, run = 3)

Run the code above in your browser using DataLab