Extracts and prints model statistics simulated with icm.
Usage
# S3 method for class 'icm'
summary(object, at, digits = 3, ...)Details
This function provides summary statistics for the main epidemiological
outcomes (state and transition size and prevalence) from an icm model.
Time-specific summary measures are provided, so it is necessary to input a
time of interest.
Examples
## Stochastic ICM SI model with 3 simulations
param <- param.icm(inf.prob = 0.2, act.rate = 1)
init <- init.icm(s.num = 500, i.num = 1)
control <- control.icm(type = "SI", nsteps = 50,
nsims = 5, verbose = FALSE)
mod <- icm(param, init, control)
summary(mod, at = 25)
#> EpiModel Summary
#> =======================
#> Model class: icm
#>
#> Simulation Details
#> -----------------------
#> Model type: SI
#> No. simulations: 5
#> No. time steps: 50
#> No. groups: 1
#>
#> Model Statistics
#> ------------------------------
#> Time: 25
#> ------------------------------
#> mean sd pct
#> Suscept. 441.6 29.888 0.881
#> Infect. 59.4 29.888 0.119
#> Total 501.0 0.000 1.000
#> S -> I 9.6 5.683 NA
#> ------------------------------
summary(mod, at = 50)
#> EpiModel Summary
#> =======================
#> Model class: icm
#>
#> Simulation Details
#> -----------------------
#> Model type: SI
#> No. simulations: 5
#> No. time steps: 50
#> No. groups: 1
#>
#> Model Statistics
#> ------------------------------
#> Time: 50
#> ------------------------------
#> mean sd pct
#> Suscept. 39.0 38.347 0.078
#> Infect. 462.0 38.347 0.922
#> Total 501.0 0.000 1.000
#> S -> I 6.2 4.970 NA
#> ------------------------------